@@ -5,7 +5,7 @@ package Test::Mojibake;
 use strict;
 use warnings qw(all);
 
-our $VERSION = '1.2'; # VERSION
+our $VERSION = '1.3'; # VERSION
 
 use File::Spec::Functions;
 use Test::Builder;
@@ -320,10 +320,17 @@ Test::Mojibake - check your source for encoding misbehavior.
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 SYNOPSIS
 
+    # Test::Mojibake lets you check for inconsistencies in source/documentation encoding, and report its results in standard Test::Simple fashion.
+    no strict 'vars';
+
+    use Test::Mojibake;
+    file_encoding_ok($file, 'Valid encoding');
+    done_testing($num_tests);
+
 =head1 DESCRIPTION
 
 Many modern text editors automatically save files using UTF-8 codification, however, L<perl> interpreter does not expects it I<by default>. Whereas this does not represent a big deal on (most) backend-oriented programs, Web framework (L<Catalyst|http://www.catalystframework.org/>, L<Mojolicious|http://mojolicio.us/>) based applications will suffer of so-called L<Mojibake|http://en.wikipedia.org/wiki/Mojibake> (lit. "unintelligible sequence of characters").
@@ -420,14 +427,6 @@ Return codes:
 
 L<Unicode::CheckUTF8> is highly recommended, however, it is optional and this function will fallback to the Pure Perl implementation of the following PHP code: L<http://www.php.net/manual/en/function.utf8-encode.php#85293>
 
-=for test_synopsis my ($file, $num_tests);
-
-    # Test::Mojibake lets you check for inconsistencies in source/documentation encoding, and report its results in standard Test::Simple fashion.
-
-    use Test::Mojibake;
-    file_encoding_ok($file, 'Valid encoding');
-    done_testing($num_tests);
-
 =head1 SAMPLE TEST SCRIPT
 
 Module authors can include the following in a F<t/mojibake.t> file and have L<Test::Mojibake> automatically find and check all source files in a module distribution:
